==> hinemos_src-3.2.2.tar.gz: HinemosManager/src_ping/com/clustercontrol/ping/factory/SelectMonitorPing.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.ping.factory;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.monitor.run.factory.SelectMonitor;
import com.clustercontrol.ping.bean.PingCheckInfo;
import com.clustercontrol.ping.ejb.entity.MonitorPingInfoLocal;
import com.clustercontrol.ping.ejb.entity.MonitorPingInfoUtil;
import com.clustercontrol.ping.ejb.entity.MonitorPingInfoPK;

/**
 * ping監視判定情報を検索するクラス<BR>
 *
 * @version 2.0.0
 * @since 2.0.0
 */
public class SelectMonitorPing extends SelectMonitor{
	
	protected static Log m_log = LogFactory.getLog( SelectMonitorPing.class );

	/* (非 Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
	 */
	@Override
	public PingCheckInfo getPingCheckInfo() throws FinderException, NamingException{
		
		// ping監視情報を取得
		MonitorPingInfoPK pk = new MonitorPingInfoPK(m_monitorId, m_monitorTypeId);
		MonitorPingInfoLocal pingLocal = MonitorPingInfoUtil.getLocalHome().findByPrimaryKey(pk);
		
		PingCheckInfo ping = new PingCheckInfo();
		ping.setMonitorTypeId(m_monitorTypeId);
		ping.setMonitorId(m_monitorId);
		ping.setRunCount(pingLocal.getRunCount());
		ping.setRunInterval(pingLocal.getRunInterval());
		ping.setTimeout(pingLocal.getTimeout());
		
		return ping;
	}
}

==> hinemos_src-4.0.3.tar.gz: HinemosManager/src_ping/com/clustercontrol/ping/factory/SelectMonitorPing.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.ping.factory;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import com.clustercontrol.monitor.run.factory.SelectMonitor;
import com.clustercontrol.ping.bean.PingCheckInfo;
import com.clustercontrol.ping.ejb.entity.MonitorPingInfoLocal;
import com.clustercontrol.ping.ejb.entity.MonitorPingInfoUtil;

/**
 * ping監視判定情報を検索するクラス<BR>
 *
 * @version 4.0.0
 * @since 2.0.0
 */
public class SelectMonitorPing extends SelectMonitor{

	/* (非 Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
	 */
	@Override
	protected PingCheckInfo getPingCheckInfo() throws FinderException, NamingException{

		// ping監視情報を取得
		MonitorPingInfoLocal pingLocal = MonitorPingInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);

		PingCheckInfo ping = new PingCheckInfo();
		ping.setMonitorTypeId(m_monitorTypeId);
		ping.setMonitorId(m_monitorId);
		ping.setRunCount(pingLocal.getRunCount());
		ping.setRunInterval(pingLocal.getRunInterval());
		ping.setTimeout(pingLocal.getTimeout());

		return ping;
	}
}
